Struct calc_lib::Definitions
source · [−]pub struct Definitions { /* private fields */ }Expand description
A list of definitions to pass into the crate to be used in the interpreter.
pub struct Definitions { /* private fields */ }A list of definitions to pass into the crate to be used in the interpreter.